<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>EffectSRConverterFactory</name>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="30"/>
        <source>SRC Plugin</source>
        <translation>SRC 插件</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="50"/>
        <source>About Sample Rate Converter Plugin</source>
        <translation>关于取样率转换插件</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="51"/>
        <source>Qmmp Sample Rate Converter Plugin</source>
        <translation>Qmmp 取样率转换插件</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SRConverterSettingsDialog</name>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="14"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>取样率转换插件设置</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="20"/>
        <source>Sample Rate (Hz):</source>
        <translation>取样率 (Hz)：</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="40"/>
        <source>Interpolation Engine:</source>
        <translation>内插引擎：</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="48"/>
        <source>Best Sinc Interpolation</source>
        <translation>最好 SINC 插入 (高品质)</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="53"/>
        <source>Medium Sinc Interpolation</source>
        <translation>一般 SINC 插入 (中品质)</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="58"/>
        <source>Fastest Sinc Interpolation</source>
        <translation>最快 SINC 插入 (低品质)</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="63"/>
        <source>ZOH Interpolation</source>
        <translation>零阶保持插入 (ZOH)</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="68"/>
        <source>Linear Interpolation</source>
        <translation>线性插入</translation>
    </message>
</context>
</TS>
